from __future__ import annotations

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal

from .._resource import SyncAPIResource, AsyncAPIResource
from .._base_client import make_request_options
import httpx
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven, Base64FileInput
# from ..types.kbs import 

from ..types.kbs import (
    volume_create_params,
    QosParam,
    SourceParam,
    VolumeDetail
)


from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)


__all__ = ["KbsResource", "AsyncKbsResource"]

class KbsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> KbsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.
        """
        return KbsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KbsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        """
        return KbsResourceWithStreamingResponse(self)
    


    def validate_delete_volume_parameters(
    self,
    id: str,
    k_tenant_id: str,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        # Validate 'id'
        if not isinstance(id, str) or not id.strip():
            raise ValueError("'id' must be a non-empty string.")

        # Validate 'k_tenant_id'
        if not isinstance(k_tenant_id, str) or not k_tenant_id.strip():
            raise ValueError("'k_tenant_id' must be a non-empty string.")

        # Validate optional dictionary parameters
        for name, param in {
            "extra_headers": extra_headers,
            "extra_query": extra_query,
            "extra_body": extra_body,
        }.items():
            if param is not None and not isinstance(param, dict):
                raise ValueError(f"'{name}' must be a dictionary if provided.")

        # Validate timeout
        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")



    def validate_create_volume_parameters(
    self,
    availability_zone,
    multiattach,
    name,
    size,
    x_region,
    volumetype,
    k_tenant_id,
    timeout=None
    
    ):
        # Required string parameters
        for param_name, param_value in {
            "availability_zone": availability_zone,
            "name": name,
            "volumetype": volumetype,
            "k_tenant_id": k_tenant_id,
        }.items():
            if not isinstance(param_value, str) or not param_value:
                raise ValueError(f"'{param_name}' must be a non-empty string.")

        # Required: multiattach
        if not isinstance(multiattach, bool):
            raise ValueError("'multiattach' must be a boolean.")

        # Required: size
        if not isinstance(size, int) or size <= 0:
            raise ValueError("'size' must be a positive integer.")


        # Optional: timeout
        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")




    def delete_volume (
        self,
        id: str,
        *,
        k_tenant_id: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a KBS Volume

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_delete_volume_parameters(
            id = id,
            k_tenant_id = k_tenant_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
            x_region = x_region
        )
        extra_headers = {
            "K-Tenant-ID": k_tenant_id,
            "x-region": x_region,
            **(extra_headers or {})
        }
        return self._delete(
            f"/kbs/v1/volumes/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def create_volume(
        self,
        *,
        availability_zone: str,
        multiattach: bool,
        name: str,
        size: int,
        volumetype: str,
        k_tenant_id: str,
        x_region: str,
        description: Optional[str] | None | NotGiven = NOT_GIVEN,
        metadata: dict| None | NotGiven = NOT_GIVEN,
        qos: QosParam | None | NotGiven = NOT_GIVEN,
        source: SourceParam | None | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeDetail:
        """
        Create a new KBS Volume

        Args:
          availability_zone: Availability zone for the volume.

          multiattach: Whether the volume can be attached to multiple instances.

          name: Name of the volume.

          size: Size of the volume in GB.

          volumetype: Type of the volume.

          description: Description of the volume.

          metadata: Metadata key-value pairs for the volume.

          qos: Quality of Service (QoS) settings for the volume.

          source: Source from which the volume is created.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_create_volume_parameters(
            availability_zone = availability_zone,
            multiattach = multiattach,
            name = name,
            size = size,
            volumetype = volumetype,
            k_tenant_id = k_tenant_id,
            timeout=timeout,
            x_region = x_region
        )

        extra_headers = {"K-Tenant-ID": k_tenant_id, **(extra_headers or {})}
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._post(
            "/kbs/v1/volumes",
            body=maybe_transform(
                {
                    "availability_zone": availability_zone,
                    "multiattach": multiattach,
                    "name": name,
                    "size": size,
                    "volumetype": volumetype,
                    "description": description,
                    "metadata": metadata,
                    "qos": qos,
                    "source": source,
                },
                volume_create_params.VolumeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VolumeDetail,
        )
    # GET VOLUME
    def retrieve_volume(
        self,
        volume_id: str,
        *,
        k_tenant_id: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeDetail:
        """
        Get details of a specific KBS Volume

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not volume_id:
            raise ValueError(f"Expected a non-empty value for `volume_id` but received {volume_id!r}")
        extra_headers = {"K-Tenant-ID": k_tenant_id, **(extra_headers or {})}
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return self._get(
            f"/kbs/v1/volumes/{volume_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VolumeDetail,
        )





class AsyncKbsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncKbsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.
        """
        return AsyncKbsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKbsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.
        """
        return AsyncKbsResourceWithStreamingResponse(self)
    


    async def validate_delete_volume_parameters(
    self,
    id: str,
    k_tenant_id: str,
    x_region,
    extra_headers=None,
    extra_query=None,
    extra_body=None,
    timeout=None
    ):
        # Validate 'id'
        if not isinstance(id, str) or not id.strip():
            raise ValueError("'id' must be a non-empty string.")

        # Validate 'k_tenant_id'
        if not isinstance(k_tenant_id, str) or not k_tenant_id.strip():
            raise ValueError("'k_tenant_id' must be a non-empty string.")

        # Validate optional dictionary parameters
        for name, param in {
            "extra_headers": extra_headers,
            "extra_query": extra_query,
            "extra_body": extra_body,
        }.items():
            if param is not None and not isinstance(param, dict):
                raise ValueError(f"'{name}' must be a dictionary if provided.")

        # Validate timeout
        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")


    async def validate_create_volume_parameters(
    self,
    availability_zone,
    multiattach,
    name,
    size,
    x_region,
    volumetype,
    k_tenant_id,
    timeout=None
    
    ):
        # Required string parameters
        for param_name, param_value in {
            "availability_zone": availability_zone,
            "name": name,
            "volumetype": volumetype,
            "k_tenant_id": k_tenant_id,
        }.items():
            if not isinstance(param_value, str) or not param_value:
                raise ValueError(f"'{param_name}' must be a non-empty string.")

        # Required: multiattach
        if not isinstance(multiattach, bool):
            raise ValueError("'multiattach' must be a boolean.")

        # Required: size
        if not isinstance(size, int) or size <= 0:
            raise ValueError("'size' must be a positive integer.")


        # Optional: timeout
        if timeout not in (None, NOT_GIVEN) and not isinstance(timeout, (int, float, httpx.Timeout)):
            raise ValueError("'timeout' must be a float, int, or httpx.Timeout if provided.")

        if x_region not in ("In-Bangalore-1", "In-Hyderabad-1"):
            raise ValueError("'x_region' must be either 'In-Bangalore-1' or 'In-Hyderabad-1'.")

    async def delete_volume(
        self,
        id: str,
        *,
        k_tenant_id: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete a KBS Volume

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_delete_volume_parameters(
            id = id,
            k_tenant_id = k_tenant_id,
            extra_headers=extra_headers,
            extra_query=extra_query,
            extra_body=extra_body,
            timeout=timeout,
            x_region = x_region
        )
        extra_headers = {
            "K-Tenant-ID": k_tenant_id,
            "x-region": x_region,
            **(extra_headers or {})
        }

        return await self._delete(
            f"/kbs/v1/volumes/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def create_volume(
        self,
        *,
        availability_zone: str,
        multiattach: bool,
        name: str,
        size: int,
        volumetype: str,
        k_tenant_id: str,
        x_region: str,
        description: Optional[str] | None | NotGiven = NOT_GIVEN,
        metadata: dict| None | NotGiven = NOT_GIVEN,
        qos: QosParam | None | NotGiven = NOT_GIVEN,
        source: SourceParam | None | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeDetail:
        """
        Create a new KBS Volume

        Args:
          availability_zone: Availability zone for the volume.

          multiattach: Whether the volume can be attached to multiple instances.

          name: Name of the volume.

          size: Size of the volume in GB.

          volumetype: Type of the volume.

          description: Description of the volume.

          metadata: Metadata key-value pairs for the volume.

          qos: Quality of Service (QoS) settings for the volume.

          source: Source from which the volume is created.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_create_volume_parameters(
            availability_zone = availability_zone,
            multiattach = multiattach,
            name = name,
            size = size,
            volumetype = volumetype,
            k_tenant_id = k_tenant_id,
            timeout=timeout,
            x_region = x_region
        )


        extra_headers = {"K-Tenant-ID": k_tenant_id, **(extra_headers or {})}
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._post(
            "/kbs/v1/volumes",
            body=await async_maybe_transform(
                {
                    "availability_zone": availability_zone,
                    "multiattach": multiattach,
                    "name": name,
                    "size": size,
                    "volumetype": volumetype,
                    "description": description,
                    "metadata": metadata,
                    "qos": qos,
                    "source": source,
                },
                volume_create_params.VolumeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VolumeDetail,
        )


    async def retrieve_volume(
        self,
        volume_id: str,
        *,
        k_tenant_id: str,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> VolumeDetail:
        """
        Get details of a specific KBS Volume

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not volume_id:
            raise ValueError(f"Expected a non-empty value for `volume_id` but received {volume_id!r}")
        extra_headers = {"K-Tenant-ID": k_tenant_id, **(extra_headers or {})}
        extra_headers = {"x-region": x_region, **(extra_headers or {})}
        return await self._get(
            f"/kbs/v1/volumes/{volume_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VolumeDetail,
        )




class KbsResourceWithRawResponse:
    def __init__(self, kbs: KbsResource) -> None:
        self._kbs = kbs

        self.delete_security_group = to_raw_response_wrapper(
            kbs.create_volume,
        )
        
        self.create_security_group = to_raw_response_wrapper(
            kbs.delete_volume,
        )

        self.create_rule = to_raw_response_wrapper(
            kbs.retrieve_volume,
        )




class AsyncKbsResourceWithRawResponse:
    def __init__(self, kbs: AsyncKbsResource) -> None:
        self._kbs = kbs

        self.delete_security_group = async_to_raw_response_wrapper(
            kbs.create_volume,
        )

        self.create_security_group = async_to_raw_response_wrapper(
            kbs.delete_volume,
        )

        self.create_rule = async_to_raw_response_wrapper(
            kbs.retrieve_volume,
        )
        


class KbsResourceWithStreamingResponse:
    def __init__(self, kbs: KbsResource) -> None:
        self._kbs = kbs

        self.delete_security_group = to_streamed_response_wrapper(
            kbs.create_volume,
        )

        self.create_security_group = to_streamed_response_wrapper(
            kbs.delete_volume,
        )

        self.create_rule = to_streamed_response_wrapper(
            kbs.retrieve_volume,
        )


class AsyncKbsResourceWithStreamingResponse:
    def __init__(self, kbs: AsyncKbsResource) -> None:
        self._kbs = kbs

        self.delete_security_group = async_to_streamed_response_wrapper(
            kbs.create_volume,
        )

        self.create_security_group = async_to_streamed_response_wrapper(
            kbs.delete_volume,
        )
        
        self.create_rule = async_to_streamed_response_wrapper(
            kbs.retrieve_volume,
        )


        

    



from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["CertRetrieveParams"]


class CertRetrieveParams(TypedDict, total=False):
    cert_id: Required[Annotated[str, PropertyInfo(alias="certId")]]



from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["HighlvlvpcCreateSubnetParams", "SubnetData"]


class HighlvlvpcCreateSubnetParams(TypedDict, total=False):
    subnet_data: Required[SubnetData]

    vpc_id: Required[str]
    """The ID of the VPC where the subnet will be created."""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="k-customer-id")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]


class SubnetData(TypedDict, total=False):
    cidr: Required[str]

    ip_version: Required[Literal[4, 6]]

    name: Required[str]

    description: Optional[str]

    gateway_ip: Optional[str]



import os
from dotenv import load_dotenv
import  traceback
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    resp = client.lb.create_load_balancer_orchestration(
        k_customer_id="enter customer id",
        x_account_id="enter account id",
        x_region="enter x_region",
         # x_region possible values "In-Bangalore-1"  

        listeners=[],


        loadbalancer_data={},
        extra_body={"security_groups": []},
    )
    
    print("Successfully created LB Orchestration:", resp)

except Exception as e:
    print("Error has occurred:", repr(e))



from typing import List, Optional
from datetime import datetime
from typing_extensions import TypeAlias

from krutrim_client._models import BaseModel


__all__ = ["BucketListResponse", "BucketListResponseItem"]


class BucketListResponseItem(BaseModel):
    anonymous_access: Optional[bool] = None
    """Whether anonymous access is allowed."""

    created_at: Optional[datetime] = None
    """Timestamp when the bucket was created."""

    description: Optional[str] = None
    """Description of the bucket."""

    name: Optional[str] = None
    """The name of the bucket."""

    region: Optional[str] = None
    """The region where the bucket is located."""

    versioning: Optional[bool] = None
    """Whether versioning is enabled."""


BucketListResponse: TypeAlias = List[BucketListResponseItem]



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load env
load_dotenv()
api_key = os.getenv("API_KEY")

# Init client
client = KrutrimClient(api_key=api_key)
try:
    resp = client.lb.get_task_status(
        x_region = "enter the x_region",
        task_id="enter the task id here"
    )
    print(f"Task status: {resp}")


except Exception as e:
    print(f"Error has occurred: {e}")


import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

# Load env
load_dotenv()
api_key = os.getenv("API_KEY")

# Init client
client = KrutrimClient(api_key=api_key)

try:

    import_cert_resp = client.certs.with_raw_response.import_file(
        cert_file="enter the path to your certificate file here",

        # form fields
        name="enter the name",
        tags="{}",   # keep "{}" if API expects JSON-like tags
        flag="0",    # use "0" or "1" as required

        # headers

        vpc_id="enter the vpc id here",
    )

    print(f"{import_cert_resp.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")




# try:

#     import_cert_resp = client.certs.with_raw_response.import_file(
#         cert_file="/Users/monissa.n1/Documents/SDK/krutrim-client-sdk/bundle.p12",

#         # form fields
#         name="certificate-name567564556556",
#         tags="{}",   # keep "{}" if API expects JSON-like tags
#         flag="0",    # use "0" or "1" as required

#         # headers

#         vpc_id="krn:vpc:colo-1:1330618268:64151bfb-efcc-4c55-914e-1e497c7fb602:vpc:8334f527-38e2-48d2-a7b5-a680bea0ca9a",
#     )

#     print(f"{import_cert_resp.json()}")

# except Exception as e:
#     print(f"Error has occurred: {e}")








# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .record import (
    RecordResource,
    AsyncRecordResource,
    RecordResourceWithRawResponse,
    AsyncRecordResourceWithRawResponse,
    RecordResourceWithStreamingResponse,
    AsyncRecordResourceWithStreamingResponse,
)
from ..._types import Body, Query, Headers, NoneType, NotGiven, NOT_GIVEN
from .zone.zone import (
    ZoneResource,
    AsyncZoneResource,
    ZoneResourceWithRawResponse,
    AsyncZoneResourceWithRawResponse,
    ZoneResourceWithStreamingResponse,
    AsyncZoneResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def zone(self) -> ZoneResource:
        return ZoneResource(self._client)

    @cached_property
    def record(self) -> RecordResource:
        return RecordResource(self._client)

    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def get_nameserver_ip(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get Name Server IP"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/dns/v1/nameserverip",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_records(
        self,
        zoneid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Records for a Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/dns/v1/records/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_service_health(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get Service Health"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/dns/v1/health",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_service_metrics(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get Service Metrics"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/dns/v1/metrics",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list_zones(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get All Zones"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            "/dns/v1/zones",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def zone(self) -> AsyncZoneResource:
        return AsyncZoneResource(self._client)

    @cached_property
    def record(self) -> AsyncRecordResource:
        return AsyncRecordResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/dns-6-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def get_nameserver_ip(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get Name Server IP"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/dns/v1/nameserverip",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_records(
        self,
        zoneid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Records for a Zone

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not zoneid:
            raise ValueError(f"Expected a non-empty value for `zoneid` but received {zoneid!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/dns/v1/records/{zoneid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_service_health(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get Service Health"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/dns/v1/health",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_service_metrics(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get Service Metrics"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/dns/v1/metrics",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list_zones(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """Get All Zones"""
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/dns/v1/zones",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_nameserver_ip = to_raw_response_wrapper(
            v1.get_nameserver_ip,
        )
        self.get_records = to_raw_response_wrapper(
            v1.get_records,
        )
        self.get_service_health = to_raw_response_wrapper(
            v1.get_service_health,
        )
        self.get_service_metrics = to_raw_response_wrapper(
            v1.get_service_metrics,
        )
        self.list_zones = to_raw_response_wrapper(
            v1.list_zones,
        )

    @cached_property
    def zone(self) -> ZoneResourceWithRawResponse:
        return ZoneResourceWithRawResponse(self._v1.zone)

    @cached_property
    def record(self) -> RecordResourceWithRawResponse:
        return RecordResourceWithRawResponse(self._v1.record)


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_nameserver_ip = async_to_raw_response_wrapper(
            v1.get_nameserver_ip,
        )
        self.get_records = async_to_raw_response_wrapper(
            v1.get_records,
        )
        self.get_service_health = async_to_raw_response_wrapper(
            v1.get_service_health,
        )
        self.get_service_metrics = async_to_raw_response_wrapper(
            v1.get_service_metrics,
        )
        self.list_zones = async_to_raw_response_wrapper(
            v1.list_zones,
        )

    @cached_property
    def zone(self) -> AsyncZoneResourceWithRawResponse:
        return AsyncZoneResourceWithRawResponse(self._v1.zone)

    @cached_property
    def record(self) -> AsyncRecordResourceWithRawResponse:
        return AsyncRecordResourceWithRawResponse(self._v1.record)


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_nameserver_ip = to_streamed_response_wrapper(
            v1.get_nameserver_ip,
        )
        self.get_records = to_streamed_response_wrapper(
            v1.get_records,
        )
        self.get_service_health = to_streamed_response_wrapper(
            v1.get_service_health,
        )
        self.get_service_metrics = to_streamed_response_wrapper(
            v1.get_service_metrics,
        )
        self.list_zones = to_streamed_response_wrapper(
            v1.list_zones,
        )

    @cached_property
    def zone(self) -> ZoneResourceWithStreamingResponse:
        return ZoneResourceWithStreamingResponse(self._v1.zone)

    @cached_property
    def record(self) -> RecordResourceWithStreamingResponse:
        return RecordResourceWithStreamingResponse(self._v1.record)


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_nameserver_ip = async_to_streamed_response_wrapper(
            v1.get_nameserver_ip,
        )
        self.get_records = async_to_streamed_response_wrapper(
            v1.get_records,
        )
        self.get_service_health = async_to_streamed_response_wrapper(
            v1.get_service_health,
        )
        self.get_service_metrics = async_to_streamed_response_wrapper(
            v1.get_service_metrics,
        )
        self.list_zones = async_to_streamed_response_wrapper(
            v1.list_zones,
        )

    @cached_property
    def zone(self) -> AsyncZoneResourceWithStreamingResponse:
        return AsyncZoneResourceWithStreamingResponse(self._v1.zone)

    @cached_property
    def record(self) -> AsyncRecordResourceWithStreamingResponse:
        return AsyncRecordResourceWithStreamingResponse(self._v1.record)



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    delete_record = client.v1.record.delete(
        recordid="enter record_id"
    )

    print(f"Successfully deleted the record")

except Exception as e:
    print(f"Exception: {e}")



from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)


try:
    delete_instance_resp = client.highlvlvpc.delete_instance(
        instanceKrn = "Enter the Instance KRN",
        deleteVolume = True,
        x_region = "Enter the region",
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )
    print(f"Deleted Successfully")

except Exception as e:
    print(f"Exception has occured: {e}")


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    fetch_zone = client.v1.zone.with_raw_response.fetch()

    print(f"Successfully fetched the zone: {fetch_zone.json()}")

except Exception as e:
    print(f"Exception: {e}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["NodeGroupUpgradeParams", "ScalingConfig"]


class NodeGroupUpgradeParams(TypedDict, total=False):
    cluster_krn: Required[Annotated[str, PropertyInfo(alias="clusterKrn")]]

    scaling_config: Annotated[ScalingConfig, PropertyInfo(alias="scalingConfig")]


class ScalingConfig(TypedDict, total=False):
    desired_size: Annotated[int, PropertyInfo(alias="desiredSize")]

    max_size: Annotated[int, PropertyInfo(alias="maxSize")]

    min_size: Annotated[int, PropertyInfo(alias="minSize")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["V1UpscaleAsgParams"]


class V1UpscaleAsgParams(TypedDict, total=False):
    asg_krn: str

    attach_floating_ip: bool

    desired_vm_count: int

    vpc_krn: str


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1GetLaunchTemplatesParams"]


class V1GetLaunchTemplatesParams(TypedDict, total=False):
    page: Required[int]

    size: Required[int]

    vpc_id: Required[str]

    x_region: Annotated[str, PropertyInfo(alias="x-region")]


from krutrim_client import KrutrimClient
import os
from dotenv import load_dotenv

load_dotenv()

api_key = os.getenv("api_key")

client = KrutrimClient(api_key = api_key)

try:
    Create_Subnet_Response = client.highlvlvpc.create_subnet(

        subnet_data = {
        "cidr": "10.0.39.0/25",
        "gateway_ip": "10.0.39.1",
        "name": "Enter the Subnet Name",
        "description": "Enter the subnet description",
        "ip_version": 4,
        "ingress": False,
        "egress": False
    },
    vpc_id = "Enter the VPC ID",
    router_krn = "Enter the Router ID",
    timeout = 1000,
    x_region = "Enter the region"
    # x_region possible values "In-Bangalore-1","In-Hyderabad-1"

    )
    print(f"Successfully created the Subnet")

except Exception as e:
    print(f"Exception: {e}")       


#

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["HighlvlvpcSearchVpcsParams"]


class HighlvlvpcSearchVpcsParams(TypedDict, total=False):
    name: str
    """Filter VPCs by name."""

    page: int
    """Page number for pagination."""

    size: int
    """Number of items to return per page."""

    status: str
    """Filter VPCs by status."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .lb import (
    HighlvlResource,
    AsyncHighlvlResource,
    HighlvlResourceWithRawResponse,
    AsyncHighlvlResourceWithRawResponse,
    HighlvlResourceWithStreamingResponse,
    AsyncHighlvlResourceWithStreamingResponse,
)

__all__ = [
    "HighlvlResource",
    "AsyncHighlvlResource",
    "HighlvlResourceWithRawResponse",
    "AsyncHighlvlResourceWithRawResponse",
    "HighlvlResourceWithStreamingResponse",
    "AsyncHighlvlResourceWithStreamingResponse",
]


from typing import Optional

from ..._models import BaseModel

__all__ = ["V1CreateResponse"]


class V1CreateResponse(BaseModel):
    id: Optional[str] = None
    """The KRN of the newly created Security Group."""

    message: Optional[str] = None
    """A confirmation message."""

    name: Optional[str] = None
    """The name of the created Security Group."""

    status: Optional[str] = None
    """The status of the Security Group."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .policy_param import PolicyParam as PolicyParam
from .volume_param import VolumeParam as VolumeParam
from .v1_create_asg_params import V1CreateAsgParams as V1CreateAsgParams
from .v1_update_asg_params import V1UpdateAsgParams as V1UpdateAsgParams
from .v1_upscale_asg_params import V1UpscaleAsgParams as V1UpscaleAsgParams
from .v1_retrieve_asg_params import V1RetrieveAsgParams as V1RetrieveAsgParams
from .v1_downscale_asg_params import V1DownscaleAsgParams as V1DownscaleAsgParams
from .v1_get_launch_templates_params import V1GetLaunchTemplatesParams as V1GetLaunchTemplatesParams
from .v1_create_launch_template_params import V1CreateLaunchTemplateParams as V1CreateLaunchTemplateParams
from .v1_delete_launch_template_params import V1DeleteLaunchTemplateParams as V1DeleteLaunchTemplateParams
from .v1_update_launch_template_params import V1UpdateLaunchTemplateParams as V1UpdateLaunchTemplateParams


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, NOT_GIVEN
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.kks.clusters import node_group_create_params, node_group_upgrade_params
from typing import Optional

__all__ = ["NodeGroupsResource", "AsyncNodeGroupsResource"]


class NodeGroupsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> NodeGroupsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return NodeGroupsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> NodeGroupsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return NodeGroupsResourceWithStreamingResponse(self)

    def create(
        self,
        cluster_krn: str,
        *,
        disk_size: int | Omit = omit,
        instance_types: str | Omit = omit,
        name: str | Omit = omit,
        node_repair_config: object | Omit = omit,
        remote_access: object | Omit = omit,
        scaling_config: object | Omit = omit,
        subnets_krn: str | Omit = omit,
        labels: Optional[object] = None,  # optional object
        taints: Optional[object] = None,  # optional object
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Nodegroup

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/v1/kks/clusters/{cluster_krn}/node-groups",
            body=maybe_transform(
                {
                    "disk_size": disk_size,
                    "instance_types": instance_types,
                    "name": name,
                    "node_repair_config": node_repair_config,
                    "remote_access": remote_access,
                    "scaling_config": scaling_config,
                    "subnets_krn": subnets_krn,
                    "labels": labels,   
                    "taints": taints,   
                },
                node_group_create_params.NodeGroupCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        nodegroup_krn: str,
        *,
        cluster_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        GET Nodegroup Details

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not nodegroup_krn:
            raise ValueError(f"Expected a non-empty value for `nodegroup_krn` but received {nodegroup_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/clusters/{cluster_krn}/node-groups/{nodegroup_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List All NodeGroups

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/v1/kks/clusters/{cluster_krn}/node-groups",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete(
        self,
        nodegroup_krn: str,
        *,
        cluster_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Nodegroup

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not nodegroup_krn:
            raise ValueError(f"Expected a non-empty value for `nodegroup_krn` but received {nodegroup_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/v1/kks/clusters/{cluster_krn}/node-groups/{nodegroup_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def upgrade(
        self,
        nodegroup_krn: str,
        *,
        cluster_krn: str,
        scaling_config: node_group_upgrade_params.ScalingConfig | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Upgrade nodegroup

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not nodegroup_krn:
            raise ValueError(f"Expected a non-empty value for `nodegroup_krn` but received {nodegroup_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            f"/v1/kks/clusters/{cluster_krn}/node-groups/{nodegroup_krn}",
            body=maybe_transform({"scaling_config": scaling_config}, node_group_upgrade_params.NodeGroupUpgradeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncNodeGroupsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncNodeGroupsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/kks-python#accessing-raw-response-data-eg-headers
        """
        return AsyncNodeGroupsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncNodeGroupsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/kks-python#with_streaming_response
        """
        return AsyncNodeGroupsResourceWithStreamingResponse(self)

    async def create(
        self,
        cluster_krn: str,
        *,
        disk_size: int | Omit = omit,
        instance_types: str | Omit = omit,
        name: str | Omit = omit,
        node_repair_config: node_group_create_params.NodeRepairConfig | Omit = omit,
        remote_access: node_group_create_params.RemoteAccess | Omit = omit,
        scaling_config: node_group_create_params.ScalingConfig | Omit = omit,
        subnets_krn: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Nodegroup

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/v1/kks/clusters/{cluster_krn}/node-groups",
            body=await async_maybe_transform(
                {
                    "disk_size": disk_size,
                    "instance_types": instance_types,
                    "name": name,
                    "node_repair_config": node_repair_config,
                    "remote_access": remote_access,
                    "scaling_config": scaling_config,
                    "subnets_krn": subnets_krn,
                },
                node_group_create_params.NodeGroupCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        nodegroup_krn: str,
        *,
        cluster_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        GET Nodegroup Details

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not nodegroup_krn:
            raise ValueError(f"Expected a non-empty value for `nodegroup_krn` but received {nodegroup_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/kks/clusters/{cluster_krn}/node-groups/{nodegroup_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        cluster_krn: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List All NodeGroups

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v1/kks/clusters/{cluster_krn}/node-groups",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete(
        self,
        nodegroup_krn: str,
        *,
        cluster_krn: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Nodegroup

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not nodegroup_krn:
            raise ValueError(f"Expected a non-empty value for `nodegroup_krn` but received {nodegroup_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/v1/kks/clusters/{cluster_krn}/node-groups/{nodegroup_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def upgrade(
        self,
        nodegroup_krn: str,
        *,
        cluster_krn: str,
        scaling_config: node_group_upgrade_params.ScalingConfig | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Upgrade nodegroup

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not cluster_krn:
            raise ValueError(f"Expected a non-empty value for `cluster_krn` but received {cluster_krn!r}")
        if not nodegroup_krn:
            raise ValueError(f"Expected a non-empty value for `nodegroup_krn` but received {nodegroup_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            f"/v1/kks/clusters/{cluster_krn}/node-groups/{nodegroup_krn}",
            body=await async_maybe_transform(
                {"scaling_config": scaling_config}, node_group_upgrade_params.NodeGroupUpgradeParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class NodeGroupsResourceWithRawResponse:
    def __init__(self, node_groups: NodeGroupsResource) -> None:
        self._node_groups = node_groups

        self.create = to_raw_response_wrapper(
            node_groups.create,
        )
        self.retrieve = to_raw_response_wrapper(
            node_groups.retrieve,
        )
        self.list = to_raw_response_wrapper(
            node_groups.list,
        )
        self.delete = to_raw_response_wrapper(
            node_groups.delete,
        )
        self.upgrade = to_raw_response_wrapper(
            node_groups.upgrade,
        )


class AsyncNodeGroupsResourceWithRawResponse:
    def __init__(self, node_groups: AsyncNodeGroupsResource) -> None:
        self._node_groups = node_groups

        self.create = async_to_raw_response_wrapper(
            node_groups.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            node_groups.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            node_groups.list,
        )
        self.delete = async_to_raw_response_wrapper(
            node_groups.delete,
        )
        self.upgrade = async_to_raw_response_wrapper(
            node_groups.upgrade,
        )


class NodeGroupsResourceWithStreamingResponse:
    def __init__(self, node_groups: NodeGroupsResource) -> None:
        self._node_groups = node_groups

        self.create = to_streamed_response_wrapper(
            node_groups.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            node_groups.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            node_groups.list,
        )
        self.delete = to_streamed_response_wrapper(
            node_groups.delete,
        )
        self.upgrade = to_streamed_response_wrapper(
            node_groups.upgrade,
        )


class AsyncNodeGroupsResourceWithStreamingResponse:
    def __init__(self, node_groups: AsyncNodeGroupsResource) -> None:
        self._node_groups = node_groups

        self.create = async_to_streamed_response_wrapper(
            node_groups.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            node_groups.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            node_groups.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            node_groups.delete,
        )
        self.upgrade = async_to_streamed_response_wrapper(
            node_groups.upgrade,
        )
